# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1/proto/common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1/proto/common.proto",
    package="google.cloud.datacatalog.v1",
    syntax="proto3",
    serialized_options=b"\n\037com.google.cloud.datacatalog.v1P\001ZFgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1;datacatalog\370\001\001\252\002\033Google.Cloud.DataCatalog.V1\312\002\033Google\\Cloud\\DataCatalog\\V1\352\002\036Google::Cloud::DataCatalog::V1",
    serialized_pb=b"\n.google/cloud/datacatalog_v1/proto/common.proto\x12\x1bgoogle.cloud.datacatalog.v1*U\n\x10IntegratedSystem\x12!\n\x1dINTEGRATED_SYSTEM_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x42IGQUERY\x10\x01\x12\x10\n\x0c\x43LOUD_PUBSUB\x10\x02\x42\xcb\x01\n\x1f\x63om.google.cloud.datacatalog.v1P\x01ZFgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1;datacatalog\xf8\x01\x01\xaa\x02\x1bGoogle.Cloud.DataCatalog.V1\xca\x02\x1bGoogle\\Cloud\\DataCatalog\\V1\xea\x02\x1eGoogle::Cloud::DataCatalog::V1b\x06proto3",
)

_INTEGRATEDSYSTEM = _descriptor.EnumDescriptor(
    name="IntegratedSystem",
    full_name="google.cloud.datacatalog.v1.IntegratedSystem",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="INTEGRATED_SYSTEM_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="BIGQUERY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CLOUD_PUBSUB", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=79,
    serialized_end=164,
)
_sym_db.RegisterEnumDescriptor(_INTEGRATEDSYSTEM)

IntegratedSystem = enum_type_wrapper.EnumTypeWrapper(_INTEGRATEDSYSTEM)
INTEGRATED_SYSTEM_UNSPECIFIED = 0
BIGQUERY = 1
CLOUD_PUBSUB = 2


DESCRIPTOR.enum_types_by_name["IntegratedSystem"] = _INTEGRATEDSYSTEM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.datacatalog_v1beta1.proto import (
    policytagmanagerserialization_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2,
)


class PolicyTagManagerSerializationStub(object):
    """Policy tag manager serialization API service allows clients to manipulate
  their taxonomies and policy tags data with serialized format.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.ImportTaxonomies = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization/ImportTaxonomies",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ImportTaxonomiesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ImportTaxonomiesResponse.FromString,
        )
        self.ExportTaxonomies = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization/ExportTaxonomies",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ExportTaxonomiesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ExportTaxonomiesResponse.FromString,
        )


class PolicyTagManagerSerializationServicer(object):
    """Policy tag manager serialization API service allows clients to manipulate
  their taxonomies and policy tags data with serialized format.
  """

    def ImportTaxonomies(self, request, context):
        """Imports all taxonomies and their policy tags to a project as new
    taxonomies.

    This method provides a bulk taxonomy / policy tag creation using nested
    proto structure.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportTaxonomies(self, request, context):
        """Exports all taxonomies and their policy tags in a project.

    This method generates SerializedTaxonomy protos with nested policy tags
    that can be used as an input for future ImportTaxonomies calls.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PolicyTagManagerSerializationServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ImportTaxonomies": grpc.unary_unary_rpc_method_handler(
            servicer.ImportTaxonomies,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ImportTaxonomiesRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ImportTaxonomiesResponse.SerializeToString,
        ),
        "ExportTaxonomies": grpc.unary_unary_rpc_method_handler(
            servicer.ExportTaxonomies,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ExportTaxonomiesRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanagerserialization__pb2.ExportTaxonomiesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1/proto/search.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.cloud.datacatalog_v1.proto import (
    common_pb2 as google_dot_cloud_dot_datacatalog__v1_dot_proto_dot_common__pb2,
)
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1/proto/search.proto",
    package="google.cloud.datacatalog.v1",
    syntax="proto3",
    serialized_options=b"\n\037com.google.cloud.datacatalog.v1P\001ZFgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1;datacatalog\370\001\001\252\002\033Google.Cloud.DataCatalog.V1\312\002\033Google\\Cloud\\DataCatalog\\V1\352\002\036Google::Cloud::DataCatalog::V1",
    serialized_pb=b'\n.google/cloud/datacatalog_v1/proto/search.proto\x12\x1bgoogle.cloud.datacatalog.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a.google/cloud/datacatalog_v1/proto/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xb4\x02\n\x13SearchCatalogResult\x12I\n\x12search_result_type\x18\x01 \x01(\x0e\x32-.google.cloud.datacatalog.v1.SearchResultType\x12\x1d\n\x15search_result_subtype\x18\x02 \x01(\t\x12\x1e\n\x16relative_resource_name\x18\x03 \x01(\t\x12\x17\n\x0flinked_resource\x18\x04 \x01(\t\x12O\n\x11integrated_system\x18\x08 \x01(\x0e\x32-.google.cloud.datacatalog.v1.IntegratedSystemB\x03\xe0\x41\x03H\x00\x12\x1f\n\x15user_specified_system\x18\t \x01(\tH\x00\x42\x08\n\x06system*d\n\x10SearchResultType\x12"\n\x1eSEARCH_RESULT_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x10\n\x0cTAG_TEMPLATE\x10\x02\x12\x0f\n\x0b\x45NTRY_GROUP\x10\x03\x42\xcb\x01\n\x1f\x63om.google.cloud.datacatalog.v1P\x01ZFgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1;datacatalog\xf8\x01\x01\xaa\x02\x1bGoogle.Cloud.DataCatalog.V1\xca\x02\x1bGoogle\\Cloud\\DataCatalog\\V1\xea\x02\x1eGoogle::Cloud::DataCatalog::V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)

_SEARCHRESULTTYPE = _descriptor.EnumDescriptor(
    name="SearchResultType",
    full_name="google.cloud.datacatalog.v1.SearchResultType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SEARCH_RESULT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ENTRY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TAG_TEMPLATE", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ENTRY_GROUP", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=504,
    serialized_end=604,
)
_sym_db.RegisterEnumDescriptor(_SEARCHRESULTTYPE)

SearchResultType = enum_type_wrapper.EnumTypeWrapper(_SEARCHRESULTTYPE)
SEARCH_RESULT_TYPE_UNSPECIFIED = 0
ENTRY = 1
TAG_TEMPLATE = 2
ENTRY_GROUP = 3


_SEARCHCATALOGRESULT = _descriptor.Descriptor(
    name="SearchCatalogResult",
    full_name="google.cloud.datacatalog.v1.SearchCatalogResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="search_result_type",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.search_result_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="search_result_subtype",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.search_result_subtype",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="relative_resource_name",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.relative_resource_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="linked_resource",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.linked_resource",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="integrated_system",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.integrated_system",
            index=4,
            number=8,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_specified_system",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.user_specified_system",
            index=5,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="system",
            full_name="google.cloud.datacatalog.v1.SearchCatalogResult.system",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=194,
    serialized_end=502,
)

_SEARCHCATALOGRESULT.fields_by_name["search_result_type"].enum_type = _SEARCHRESULTTYPE
_SEARCHCATALOGRESULT.fields_by_name[
    "integrated_system"
].enum_type = (
    google_dot_cloud_dot_datacatalog__v1_dot_proto_dot_common__pb2._INTEGRATEDSYSTEM
)
_SEARCHCATALOGRESULT.oneofs_by_name["system"].fields.append(
    _SEARCHCATALOGRESULT.fields_by_name["integrated_system"]
)
_SEARCHCATALOGRESULT.fields_by_name[
    "integrated_system"
].containing_oneof = _SEARCHCATALOGRESULT.oneofs_by_name["system"]
_SEARCHCATALOGRESULT.oneofs_by_name["system"].fields.append(
    _SEARCHCATALOGRESULT.fields_by_name["user_specified_system"]
)
_SEARCHCATALOGRESULT.fields_by_name[
    "user_specified_system"
].containing_oneof = _SEARCHCATALOGRESULT.oneofs_by_name["system"]
DESCRIPTOR.message_types_by_name["SearchCatalogResult"] = _SEARCHCATALOGRESULT
DESCRIPTOR.enum_types_by_name["SearchResultType"] = _SEARCHRESULTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchCatalogResult = _reflection.GeneratedProtocolMessageType(
    "SearchCatalogResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHCATALOGRESULT,
        "__module__": "google.cloud.datacatalog_v1.proto.search_pb2",
        "__doc__": """A result that appears in the response of a search request.
  Each result captures details of one entry that matches the search.
  
  
  Attributes:
      search_result_type:
          Type of the search result. This field can be used to determine
          which Get method to call to fetch the full resource.
      search_result_subtype:
          Sub-type of the search result. This is a dot-delimited
          description of the resource’s full type, and is the same as
          the value callers would provide in the “type” search facet.
          Examples: ``entry.table``, ``entry.dataStream``,
          ``tagTemplate``.
      relative_resource_name:
          The relative resource name of the resource in URL format.
          Examples:  -  ``projects/{project_id}/locations/{location_id}/
          entryGroups/{entry_group_id}/entries/{entry_id}`` -
          ``projects/{project_id}/tagTemplates/{tag_template_id}``
      linked_resource:
          The full name of the cloud resource the entry belongs to. See:
          https://cloud.google.com/apis/design/resource_names#full_resou
          rce_name. Example:  -  ``//bigquery.googleapis.com/projects/pr
          ojectId/datasets/datasetId/tables/tableId``
      system:
          The source system of the entry. Only applicable when
          ``search_result_type`` is ENTRY.
      integrated_system:
          Output only. This field indicates the entry’s source system
          that Data Catalog integrates with, such as BigQuery or Cloud
          Pub/Sub.
      user_specified_system:
          This field indicates the entry’s source system that Data
          Catalog does not integrate with.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1.SearchCatalogResult)
    },
)
_sym_db.RegisterMessage(SearchCatalogResult)


DESCRIPTOR._options = None
_SEARCHCATALOGRESULT.fields_by_name["integrated_system"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1/proto/gcs_fileset_spec.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.cloud.datacatalog_v1.proto import (
    timestamps_pb2 as google_dot_cloud_dot_datacatalog__v1_dot_proto_dot_timestamps__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1/proto/gcs_fileset_spec.proto",
    package="google.cloud.datacatalog.v1",
    syntax="proto3",
    serialized_options=b"\n\037com.google.cloud.datacatalog.v1P\001ZFgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1;datacatalog\370\001\001\252\002\033Google.Cloud.DataCatalog.V1\312\002\033Google\\Cloud\\DataCatalog\\V1\352\002\036Google::Cloud::DataCatalog::V1",
    serialized_pb=b'\n8google/cloud/datacatalog_v1/proto/gcs_fileset_spec.proto\x12\x1bgoogle.cloud.datacatalog.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32google/cloud/datacatalog_v1/proto/timestamps.proto"z\n\x0eGcsFilesetSpec\x12\x1a\n\rfile_patterns\x18\x01 \x03(\tB\x03\xe0\x41\x02\x12L\n\x15sample_gcs_file_specs\x18\x02 \x03(\x0b\x32(.google.cloud.datacatalog.v1.GcsFileSpecB\x03\xe0\x41\x03"\x8a\x01\n\x0bGcsFileSpec\x12\x16\n\tfile_path\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12J\n\x0egcs_timestamps\x18\x02 \x01(\x0b\x32-.google.cloud.datacatalog.v1.SystemTimestampsB\x03\xe0\x41\x03\x12\x17\n\nsize_bytes\x18\x04 \x01(\x03\x42\x03\xe0\x41\x03\x42\xcb\x01\n\x1f\x63om.google.cloud.datacatalog.v1P\x01ZFgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1;datacatalog\xf8\x01\x01\xaa\x02\x1bGoogle.Cloud.DataCatalog.V1\xca\x02\x1bGoogle\\Cloud\\DataCatalog\\V1\xea\x02\x1eGoogle::Cloud::DataCatalog::V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1_dot_proto_dot_timestamps__pb2.DESCRIPTOR,
    ],
)


_GCSFILESETSPEC = _descriptor.Descriptor(
    name="GcsFilesetSpec",
    full_name="google.cloud.datacatalog.v1.GcsFilesetSpec",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="file_patterns",
            full_name="google.cloud.datacatalog.v1.GcsFilesetSpec.file_patterns",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="sample_gcs_file_specs",
            full_name="google.cloud.datacatalog.v1.GcsFilesetSpec.sample_gcs_file_specs",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=174,
    serialized_end=296,
)


_GCSFILESPEC = _descriptor.Descriptor(
    name="GcsFileSpec",
    full_name="google.cloud.datacatalog.v1.GcsFileSpec",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="file_path",
            full_name="google.cloud.datacatalog.v1.GcsFileSpec.file_path",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="gcs_timestamps",
            full_name="google.cloud.datacatalog.v1.GcsFileSpec.gcs_timestamps",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="size_bytes",
            full_name="google.cloud.datacatalog.v1.GcsFileSpec.size_bytes",
            index=2,
            number=4,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=299,
    serialized_end=437,
)

_GCSFILESETSPEC.fields_by_name["sample_gcs_file_specs"].message_type = _GCSFILESPEC
_GCSFILESPEC.fields_by_name[
    "gcs_timestamps"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1_dot_proto_dot_timestamps__pb2._SYSTEMTIMESTAMPS
)
DESCRIPTOR.message_types_by_name["GcsFilesetSpec"] = _GCSFILESETSPEC
DESCRIPTOR.message_types_by_name["GcsFileSpec"] = _GCSFILESPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GcsFilesetSpec = _reflection.GeneratedProtocolMessageType(
    "GcsFilesetSpec",
    (_message.Message,),
    {
        "DESCRIPTOR": _GCSFILESETSPEC,
        "__module__": "google.cloud.datacatalog_v1.proto.gcs_fileset_spec_pb2",
        "__doc__": """Describes a Cloud Storage fileset entry.
  
  
  Attributes:
      file_patterns:
          Required. Patterns to identify a set of files in Google Cloud
          Storage. See `Cloud Storage documentation
          </storage/docs/gsutil/addlhelp/WildcardNames>`__ for more
          information. Note that bucket wildcards are currently not
          supported.  Examples of valid file_patterns:  -
          ``gs://bucket_name/dir/*``: matches all files within
          ``bucket_name/dir`` directory. -  ``gs://bucket_name/dir/**``:
          matches all files in ``bucket_name/dir``    spanning all
          subdirectories. -  ``gs://bucket_name/file*``: matches files
          prefixed by ``file`` in    ``bucket_name`` -
          ``gs://bucket_name/??.txt``: matches files with two characters
          followed by ``.txt`` in ``bucket_name`` -
          ``gs://bucket_name/[aeiou].txt``: matches files that contain a
          single    vowel character followed by ``.txt`` in
          ``bucket_name`` -  ``gs://bucket_name/[a-m].txt``: matches
          files that contain ``a``,    ``b``, … or ``m`` followed by
          ``.txt`` in ``bucket_name`` -  ``gs://bucket_name/a/*/b``:
          matches all files in ``bucket_name`` that    match ``a/*/b``
          pattern, such as ``a/c/b``, ``a/d/b`` -
          ``gs://another_bucket/a.txt``: matches
          ``gs://another_bucket/a.txt``  You can combine wildcards to
          provide more powerful matches, for example:  -
          ``gs://bucket_name/[a-m]??.j*g``
      sample_gcs_file_specs:
          Output only. Sample files contained in this fileset, not all
          files contained in this fileset are represented here.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1.GcsFilesetSpec)
    },
)
_sym_db.RegisterMessage(GcsFilesetSpec)

GcsFileSpec = _reflection.GeneratedProtocolMessageType(
    "GcsFileSpec",
    (_message.Message,),
    {
        "DESCRIPTOR": _GCSFILESPEC,
        "__module__": "google.cloud.datacatalog_v1.proto.gcs_fileset_spec_pb2",
        "__doc__": """Specifications of a single file in Cloud Storage.
  
  
  Attributes:
      file_path:
          Required. The full file path. Example:
          ``gs://bucket_name/a/b.txt``.
      gcs_timestamps:
          Output only. Timestamps about the Cloud Storage file.
      size_bytes:
          Output only. The size of the file, in bytes.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1.GcsFileSpec)
    },
)
_sym_db.RegisterMessage(GcsFileSpec)


DESCRIPTOR._options = None
_GCSFILESETSPEC.fields_by_name["file_patterns"]._options = None
_GCSFILESETSPEC.fields_by_name["sample_gcs_file_specs"]._options = None
_GCSFILESPEC.fields_by_name["file_path"]._options = None
_GCSFILESPEC.fields_by_name["gcs_timestamps"]._options = None
_GCSFILESPEC.fields_by_name["size_bytes"]._options = None
# @@protoc_insertion_point(module_scope)
